"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.dataset.v1.dataset_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DescribeDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset to describe."""
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id"]) -> None: ...

global___DescribeDatasetRequest = DescribeDatasetRequest

@typing.final
class DescribeDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_FIELD_NUMBER: builtins.int
    @property
    def dataset(self) -> yandex.cloud.ai.dataset.v1.dataset_pb2.DatasetInfo:
        """Information about the dataset."""

    def __init__(
        self,
        *,
        dataset: yandex.cloud.ai.dataset.v1.dataset_pb2.DatasetInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dataset", b"dataset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dataset", b"dataset"]) -> None: ...

global___DescribeDatasetResponse = DescribeDatasetResponse

@typing.final
class ValidateDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset to validate."""
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id"]) -> None: ...

global___ValidateDatasetRequest = ValidateDatasetRequest

@typing.final
class ValidateDatasetMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    VALID_ROWS_FIELD_NUMBER: builtins.int
    PROCESSED_ROWS_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset."""
    valid_rows: builtins.int
    """Count of valid rows among currently processed rows in the dataset."""
    processed_rows: builtins.int
    """Count of currently processed rows in the dataset."""
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        valid_rows: builtins.int = ...,
        processed_rows: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id", "processed_rows", b"processed_rows", "valid_rows", b"valid_rows"]) -> None: ...

global___ValidateDatasetMetadata = ValidateDatasetMetadata

@typing.final
class ValidateDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    IS_VALID_FIELD_NUMBER: builtins.int
    ERRORS_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset."""
    is_valid: builtins.bool
    """Validity marker."""
    @property
    def errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.dataset.v1.dataset_pb2.ValidationError]:
        """A list of the dataset validation errors."""

    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        is_valid: builtins.bool = ...,
        errors: collections.abc.Iterable[yandex.cloud.ai.dataset.v1.dataset_pb2.ValidationError] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id", "errors", b"errors", "is_valid", b"is_valid"]) -> None: ...

global___ValidateDatasetResponse = ValidateDatasetResponse

@typing.final
class DeleteDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset to delete."""
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id"]) -> None: ...

global___DeleteDatasetRequest = DeleteDatasetRequest

@typing.final
class DeleteDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteDatasetResponse = DeleteDatasetResponse

@typing.final
class CreateDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TASK_TYPE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    UPLOAD_FORMAT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the dataset."""
    folder_id: builtins.str
    """Folder ID of the dataset."""
    description: builtins.str
    """Description of the dataset. Optional."""
    metadata: builtins.str
    """Metadata of the dataset. Optional."""
    task_type: builtins.str
    """Task type of the dataset."""
    upload_format: builtins.str
    """Upload format of the dataset.
    The list of supported upload formats can be retrieved via ListUploadFormats method.
    """
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the dataset. Optional."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        folder_id: builtins.str = ...,
        description: builtins.str = ...,
        metadata: builtins.str = ...,
        task_type: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        upload_format: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "metadata", b"metadata", "name", b"name", "task_type", b"task_type", "upload_format", b"upload_format"]) -> None: ...

global___CreateDatasetRequest = CreateDatasetRequest

@typing.final
class CreateDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    DATASET_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the created dataset."""
    @property
    def dataset(self) -> yandex.cloud.ai.dataset.v1.dataset_pb2.DatasetInfo:
        """Information about the dataset."""

    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        dataset: yandex.cloud.ai.dataset.v1.dataset_pb2.DatasetInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dataset", b"dataset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dataset", b"dataset", "dataset_id", b"dataset_id"]) -> None: ...

global___CreateDatasetResponse = CreateDatasetResponse

@typing.final
class UpdateDatasetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DATASET_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset to update."""
    name: builtins.str
    """Name of the dataset."""
    description: builtins.str
    """Description of the dataset."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """gRPC field mask."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the dataset."""

    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id", "description", b"description", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateDatasetRequest = UpdateDatasetRequest

@typing.final
class UpdateDatasetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_FIELD_NUMBER: builtins.int
    @property
    def dataset(self) -> yandex.cloud.ai.dataset.v1.dataset_pb2.DatasetInfo:
        """Information about updated dataset."""

    def __init__(
        self,
        *,
        dataset: yandex.cloud.ai.dataset.v1.dataset_pb2.DatasetInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dataset", b"dataset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dataset", b"dataset"]) -> None: ...

global___UpdateDatasetResponse = UpdateDatasetResponse

@typing.final
class GetUploadDraftUrlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    SIZE_BYTES_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset to upload."""
    size_bytes: builtins.int
    """Size in bytes of the dataset to upload."""
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        size_bytes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id", "size_bytes", b"size_bytes"]) -> None: ...

global___GetUploadDraftUrlRequest = GetUploadDraftUrlRequest

@typing.final
class GetUploadDraftUrlResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    UPLOAD_URL_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset."""
    upload_url: builtins.str
    """S3 presigned URL for upload."""
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        upload_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id", "upload_url", b"upload_url"]) -> None: ...

global___GetUploadDraftUrlResponse = GetUploadDraftUrlResponse

@typing.final
class StartMultipartUploadDraftRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    SIZE_BYTES_FIELD_NUMBER: builtins.int
    PARTS_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset to multipart upload."""
    size_bytes: builtins.int
    """Size in bytes of the dataset to upload."""
    parts: builtins.int
    """Number of parts in multipart upload. Optional.
    Dataset's part size should be between 5MB and 5GB.
    If not specified will be configured automatically.
    """
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        size_bytes: builtins.int = ...,
        parts: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id", "parts", b"parts", "size_bytes", b"size_bytes"]) -> None: ...

global___StartMultipartUploadDraftRequest = StartMultipartUploadDraftRequest

@typing.final
class StartMultipartUploadDraftResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    MULTIPART_UPLOAD_URLS_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset."""
    @property
    def multipart_upload_urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of S3 presigned URLs for multipart upload."""

    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        multipart_upload_urls: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id", "multipart_upload_urls", b"multipart_upload_urls"]) -> None: ...

global___StartMultipartUploadDraftResponse = StartMultipartUploadDraftResponse

@typing.final
class UploadedPartInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PART_NUM_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    part_num: builtins.int
    """Sequence number of the uploaded part."""
    etag: builtins.str
    """Etag of the uploaded part."""
    def __init__(
        self,
        *,
        part_num: builtins.int = ...,
        etag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["etag", b"etag", "part_num", b"part_num"]) -> None: ...

global___UploadedPartInfo = UploadedPartInfo

@typing.final
class FinishMultipartUploadDraftRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    UPLOADED_PARTS_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset."""
    @property
    def uploaded_parts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___UploadedPartInfo]:
        """Information about uploaded parts from S3 API."""

    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
        uploaded_parts: collections.abc.Iterable[global___UploadedPartInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id", "uploaded_parts", b"uploaded_parts"]) -> None: ...

global___FinishMultipartUploadDraftRequest = FinishMultipartUploadDraftRequest

@typing.final
class FinishMultipartUploadDraftResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASET_ID_FIELD_NUMBER: builtins.int
    dataset_id: builtins.str
    """ID of the dataset."""
    def __init__(
        self,
        *,
        dataset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_id", b"dataset_id"]) -> None: ...

global___FinishMultipartUploadDraftResponse = FinishMultipartUploadDraftResponse

@typing.final
class ListDatasetsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DATASET_NAME_PATTERN_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID of the datasets to list."""
    status: yandex.cloud.ai.dataset.v1.dataset_pb2.DatasetInfo.Status.ValueType
    """Status of the datasets to list. Optional."""
    dataset_name_pattern: builtins.str
    """Name substring of the datasets to list. Optional."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        status: yandex.cloud.ai.dataset.v1.dataset_pb2.DatasetInfo.Status.ValueType = ...,
        dataset_name_pattern: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["dataset_name_pattern", b"dataset_name_pattern", "folder_id", b"folder_id", "status", b"status"]) -> None: ...

global___ListDatasetsRequest = ListDatasetsRequest

@typing.final
class ListDatasetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATASETS_FIELD_NUMBER: builtins.int
    @property
    def datasets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.dataset.v1.dataset_pb2.DatasetInfo]:
        """Information about listed datasets."""

    def __init__(
        self,
        *,
        datasets: collections.abc.Iterable[yandex.cloud.ai.dataset.v1.dataset_pb2.DatasetInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["datasets", b"datasets"]) -> None: ...

global___ListDatasetsResponse = ListDatasetsResponse

@typing.final
class ListUploadFormatsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_TYPE_FIELD_NUMBER: builtins.int
    task_type: builtins.str
    """Dataset task type to list upload formats."""
    def __init__(
        self,
        *,
        task_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_type", b"task_type"]) -> None: ...

global___ListUploadFormatsRequest = ListUploadFormatsRequest

@typing.final
class ListUploadFormatsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORMATS_FIELD_NUMBER: builtins.int
    @property
    def formats(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of upload formats for the specified dataset task type."""

    def __init__(
        self,
        *,
        formats: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["formats", b"formats"]) -> None: ...

global___ListUploadFormatsResponse = ListUploadFormatsResponse



from typing import TYPE_CHECKING

from yandexcloud._wrappers.dataproc import Dataproc, InitializationAction

if TYPE_CHECKING:
    from yandexcloud._sdk import SDK


class Wrappers:
    def __init__(self, sdk: "SDK"):
        # pylint: disable-next=invalid-name
        self.Dataproc = Dataproc
        self.Dataproc.sdk = sdk
        # pylint: disable-next=invalid-name
        self.InitializationAction = InitializationAction



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.k8s.v1.cluster_pb2
import yandex.cloud.k8s.v1.node_group_pb2
import yandex.cloud.k8s.v1.node_pb2
import yandex.cloud.k8s.v1.version_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster to return."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterRequest = GetClusterRequest

@typing.final
class ListClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list Kubernetes cluster in.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListClustersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListClustersResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Cluster.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClustersRequest = ListClustersRequest

@typing.final
class ListClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListClustersRequest.page_size], use
    the `next_page_token` as the value
    for the [ListClustersRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    `next_page_token` to continue paging through the results.
    """
    @property
    def clusters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.k8s.v1.cluster_pb2.Cluster]:
        """List of Kubernetes cluster."""

    def __init__(
        self,
        *,
        clusters: collections.abc.Iterable[yandex.cloud.k8s.v1.cluster_pb2.Cluster] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["clusters", b"clusters", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClustersResponse = ListClustersResponse

@typing.final
class DeleteClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster to delete.
    To get Kubernetes cluster ID use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterRequest = DeleteClusterRequest

@typing.final
class DeleteClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterMetadata = DeleteClusterMetadata

@typing.final
class StopClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster to stop.
    To get Kubernetes cluster ID use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterRequest = StopClusterRequest

@typing.final
class StopClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster that is being stopped."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StopClusterMetadata = StopClusterMetadata

@typing.final
class StartClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster to start.
    To get Kubernetes cluster ID use a [ClusterService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterRequest = StartClusterRequest

@typing.final
class StartClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster that is being started."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___StartClusterMetadata = StartClusterMetadata

@typing.final
class UpdateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    GATEWAY_IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    MASTER_SPEC_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    NODE_SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    NETWORK_POLICY_FIELD_NUMBER: builtins.int
    IP_ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster to update.
    To get the Kubernetes cluster ID use a [ClusterService.List] request.
    """
    name: builtins.str
    """Name of the Kubernetes cluster.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the Kubernetes cluster."""
    gateway_ipv4_address: builtins.str
    """Gateway IPv4 address."""
    service_account_id: builtins.str
    """Service account to be used for provisioning Compute Cloud and VPC resources for Kubernetes cluster.
    Selected service account should have `edit` role on the folder where the Kubernetes cluster will be
    located and on the folder where selected network resides.
    """
    node_service_account_id: builtins.str
    """Service account to be used by the worker nodes of the Kubernetes cluster to access Container Registry
    or to push node logs and metrics.
    """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    @property
    def master_spec(self) -> global___MasterUpdateSpec:
        """Specification of the master update."""

    @property
    def network_policy(self) -> yandex.cloud.k8s.v1.cluster_pb2.NetworkPolicy: ...
    @property
    def ip_allocation_policy(self) -> yandex.cloud.k8s.v1.cluster_pb2.IPAllocationPolicy: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        gateway_ipv4_address: builtins.str = ...,
        master_spec: global___MasterUpdateSpec | None = ...,
        service_account_id: builtins.str = ...,
        node_service_account_id: builtins.str = ...,
        network_policy: yandex.cloud.k8s.v1.cluster_pb2.NetworkPolicy | None = ...,
        ip_allocation_policy: yandex.cloud.k8s.v1.cluster_pb2.IPAllocationPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gateway_ipv4_address", b"gateway_ipv4_address", "internet_gateway", b"internet_gateway", "ip_allocation_policy", b"ip_allocation_policy", "master_spec", b"master_spec", "network_policy", b"network_policy", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "description", b"description", "gateway_ipv4_address", b"gateway_ipv4_address", "internet_gateway", b"internet_gateway", "ip_allocation_policy", b"ip_allocation_policy", "labels", b"labels", "master_spec", b"master_spec", "name", b"name", "network_policy", b"network_policy", "node_service_account_id", b"node_service_account_id", "service_account_id", b"service_account_id", "update_mask", b"update_mask"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["internet_gateway", b"internet_gateway"]) -> typing.Literal["gateway_ipv4_address"] | None: ...

global___UpdateClusterRequest = UpdateClusterRequest

@typing.final
class MasterUpdateSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    MASTER_LOGGING_FIELD_NUMBER: builtins.int
    LOCATIONS_FIELD_NUMBER: builtins.int
    EXTERNAL_V6_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    @property
    def version(self) -> yandex.cloud.k8s.v1.version_pb2.UpdateVersionSpec:
        """Specification of the master update."""

    @property
    def maintenance_policy(self) -> yandex.cloud.k8s.v1.cluster_pb2.MasterMaintenancePolicy:
        """Maintenance policy of the master."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Master security groups."""

    @property
    def master_logging(self) -> yandex.cloud.k8s.v1.cluster_pb2.MasterLogging:
        """Cloud Logging for master components."""

    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LocationSpec]:
        """Update master instance locations."""

    @property
    def external_v6_address_spec(self) -> global___ExternalAddressSpec:
        """Specification of parameters for external IPv6 networking."""

    def __init__(
        self,
        *,
        version: yandex.cloud.k8s.v1.version_pb2.UpdateVersionSpec | None = ...,
        maintenance_policy: yandex.cloud.k8s.v1.cluster_pb2.MasterMaintenancePolicy | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        master_logging: yandex.cloud.k8s.v1.cluster_pb2.MasterLogging | None = ...,
        locations: collections.abc.Iterable[global___LocationSpec] | None = ...,
        external_v6_address_spec: global___ExternalAddressSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["external_v6_address_spec", b"external_v6_address_spec", "maintenance_policy", b"maintenance_policy", "master_logging", b"master_logging", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["external_v6_address_spec", b"external_v6_address_spec", "locations", b"locations", "maintenance_policy", b"maintenance_policy", "master_logging", b"master_logging", "security_group_ids", b"security_group_ids", "version", b"version"]) -> None: ...

global___MasterUpdateSpec = MasterUpdateSpec

@typing.final
class UpdateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___UpdateClusterMetadata = UpdateClusterMetadata

@typing.final
class CreateClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    MASTER_SPEC_FIELD_NUMBER: builtins.int
    IP_ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    GATEWAY_IPV4_ADDRESS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    NODE_SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    NETWORK_POLICY_FIELD_NUMBER: builtins.int
    KMS_PROVIDER_FIELD_NUMBER: builtins.int
    CILIUM_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a Kubernetes cluster in.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the Kubernetes cluster.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the Kubernetes cluster."""
    network_id: builtins.str
    """ID of the network."""
    gateway_ipv4_address: builtins.str
    """Gateway IPv4 address."""
    service_account_id: builtins.str
    """Service account to be used for provisioning Compute Cloud and VPC resources for Kubernetes cluster.
    Selected service account should have `edit` role on the folder where the Kubernetes cluster will be
    located and on the folder where selected network resides.
    """
    node_service_account_id: builtins.str
    """Service account to be used by the worker nodes of the Kubernetes cluster to access Container Registry or to push node logs and metrics."""
    release_channel: yandex.cloud.k8s.v1.cluster_pb2.ReleaseChannel.ValueType
    """Release channel for the master."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def master_spec(self) -> global___MasterSpec:
        """Master specification of the Kubernetes cluster."""

    @property
    def ip_allocation_policy(self) -> yandex.cloud.k8s.v1.cluster_pb2.IPAllocationPolicy:
        """IP allocation policy of the Kubernetes cluster."""

    @property
    def network_policy(self) -> yandex.cloud.k8s.v1.cluster_pb2.NetworkPolicy: ...
    @property
    def kms_provider(self) -> yandex.cloud.k8s.v1.cluster_pb2.KMSProvider:
        """KMS provider configuration."""

    @property
    def cilium(self) -> yandex.cloud.k8s.v1.cluster_pb2.Cilium: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_id: builtins.str = ...,
        master_spec: global___MasterSpec | None = ...,
        ip_allocation_policy: yandex.cloud.k8s.v1.cluster_pb2.IPAllocationPolicy | None = ...,
        gateway_ipv4_address: builtins.str = ...,
        service_account_id: builtins.str = ...,
        node_service_account_id: builtins.str = ...,
        release_channel: yandex.cloud.k8s.v1.cluster_pb2.ReleaseChannel.ValueType = ...,
        network_policy: yandex.cloud.k8s.v1.cluster_pb2.NetworkPolicy | None = ...,
        kms_provider: yandex.cloud.k8s.v1.cluster_pb2.KMSProvider | None = ...,
        cilium: yandex.cloud.k8s.v1.cluster_pb2.Cilium | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cilium", b"cilium", "gateway_ipv4_address", b"gateway_ipv4_address", "internet_gateway", b"internet_gateway", "ip_allocation_policy", b"ip_allocation_policy", "kms_provider", b"kms_provider", "master_spec", b"master_spec", "network_implementation", b"network_implementation", "network_policy", b"network_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cilium", b"cilium", "description", b"description", "folder_id", b"folder_id", "gateway_ipv4_address", b"gateway_ipv4_address", "internet_gateway", b"internet_gateway", "ip_allocation_policy", b"ip_allocation_policy", "kms_provider", b"kms_provider", "labels", b"labels", "master_spec", b"master_spec", "name", b"name", "network_id", b"network_id", "network_implementation", b"network_implementation", "network_policy", b"network_policy", "node_service_account_id", b"node_service_account_id", "release_channel", b"release_channel", "service_account_id", b"service_account_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["internet_gateway", b"internet_gateway"]) -> typing.Literal["gateway_ipv4_address"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["network_implementation", b"network_implementation"]) -> typing.Literal["cilium"] | None: ...

global___CreateClusterRequest = CreateClusterRequest

@typing.final
class CreateClusterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___CreateClusterMetadata = CreateClusterMetadata

@typing.final
class AutoUpgradeMasterMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster that is being auto upgraded."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___AutoUpgradeMasterMetadata = AutoUpgradeMasterMetadata

@typing.final
class ListClusterOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListClusterOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListClusterOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    Currently you can use filtering only on [Cluster.name] field.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterOperationsRequest = ListClusterOperationsRequest

@typing.final
class ListClusterOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListClusterOperationsRequest.page_size], use the `next_page_token` as the value
    for the [ListClusterOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified Kubernetes cluster."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListClusterOperationsResponse = ListClusterOperationsResponse

@typing.final
class ListClusterNodeGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster to list node groups in.
    To get the Kubernetes cluster ID use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListClusterNodeGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListClusterNodeGroupsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    Currently you can use filtering only on [Cluster.name] field.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterNodeGroupsRequest = ListClusterNodeGroupsRequest

@typing.final
class ListClusterNodeGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListClusterNodeGroupsRequest.page_size], use
    the `next_page_token` as the value
    for the [ListClusterNodeGroupsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    `next_page_token` to continue paging through the results.
    """
    @property
    def node_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.k8s.v1.node_group_pb2.NodeGroup]:
        """List of node groups for the specified Kubernetes cluster."""

    def __init__(
        self,
        *,
        node_groups: collections.abc.Iterable[yandex.cloud.k8s.v1.node_group_pb2.NodeGroup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "node_groups", b"node_groups"]) -> None: ...

global___ListClusterNodeGroupsResponse = ListClusterNodeGroupsResponse

@typing.final
class ListClusterNodesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster to list nodes in.
    To get the Kubernetes cluster ID use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListClusterNodesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListClusterNodeGroupsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterNodesRequest = ListClusterNodesRequest

@typing.final
class ListClusterNodesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListClusterNodesRequest.page_size], use
    the `next_page_token` as the value
    for the [ListClusterNodesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    `next_page_token` to continue paging through the results.
    """
    @property
    def nodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.k8s.v1.node_pb2.Node]:
        """List of nodes for the specified Kubernetes cluster."""

    def __init__(
        self,
        *,
        nodes: collections.abc.Iterable[yandex.cloud.k8s.v1.node_pb2.Node] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "nodes", b"nodes"]) -> None: ...

global___ListClusterNodesResponse = ListClusterNodesResponse

@typing.final
class MasterSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONAL_MASTER_SPEC_FIELD_NUMBER: builtins.int
    REGIONAL_MASTER_SPEC_FIELD_NUMBER: builtins.int
    LOCATIONS_FIELD_NUMBER: builtins.int
    ETCD_CLUSTER_SIZE_FIELD_NUMBER: builtins.int
    EXTERNAL_V4_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    EXTERNAL_V6_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    MASTER_LOGGING_FIELD_NUMBER: builtins.int
    etcd_cluster_size: builtins.int
    """Number of etcd nodes in cluster.
    Works in conjunction with [locations]. See it's documentation for details.
    Optional. If not set, will be assumed equal to the number of locations.
    """
    version: builtins.str
    """Version of Kubernetes components that runs on the master."""
    @property
    def zonal_master_spec(self) -> global___ZonalMasterSpec:
        """Specification of the zonal master."""

    @property
    def regional_master_spec(self) -> global___RegionalMasterSpec:
        """Specification of the regional master."""

    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LocationSpec]:
        """Locations specification for Kubernetes control-plane (master) instances.
        Works in conjunction with [etcd_cluster_size]. See it's documentation for details.
        Possible combinations:
        - 1 location and etcd_cluster_size = 1 - a single node cluster whose availability is limited by the availability of a single Compute Instance; downtime is expected during cluster updates.
        - 1 location and etcd_cluster_size = 3 - a highly available cluster within a single availability zone; can survive the failure of a Compute Instance, a server, or an individual server rack.
        - 3 location and etcd_cluster_size = 3 - a highly available cluster with each etcd instance located within separate availability zone; can survive the failure of a single availability zone.
        """

    @property
    def external_v4_address_spec(self) -> global___ExternalAddressSpec:
        """Specification of parameters for external IPv4 networking."""

    @property
    def external_v6_address_spec(self) -> global___ExternalAddressSpec:
        """Specification of parameters for external IPv6 networking."""

    @property
    def maintenance_policy(self) -> yandex.cloud.k8s.v1.cluster_pb2.MasterMaintenancePolicy:
        """Maintenance policy of the master."""

    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Master security groups."""

    @property
    def master_logging(self) -> yandex.cloud.k8s.v1.cluster_pb2.MasterLogging:
        """Cloud Logging for master components."""

    def __init__(
        self,
        *,
        zonal_master_spec: global___ZonalMasterSpec | None = ...,
        regional_master_spec: global___RegionalMasterSpec | None = ...,
        locations: collections.abc.Iterable[global___LocationSpec] | None = ...,
        etcd_cluster_size: builtins.int = ...,
        external_v4_address_spec: global___ExternalAddressSpec | None = ...,
        external_v6_address_spec: global___ExternalAddressSpec | None = ...,
        version: builtins.str = ...,
        maintenance_policy: yandex.cloud.k8s.v1.cluster_pb2.MasterMaintenancePolicy | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        master_logging: yandex.cloud.k8s.v1.cluster_pb2.MasterLogging | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["external_v4_address_spec", b"external_v4_address_spec", "external_v6_address_spec", b"external_v6_address_spec", "maintenance_policy", b"maintenance_policy", "master_logging", b"master_logging", "master_type", b"master_type", "regional_master_spec", b"regional_master_spec", "zonal_master_spec", b"zonal_master_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["etcd_cluster_size", b"etcd_cluster_size", "external_v4_address_spec", b"external_v4_address_spec", "external_v6_address_spec", b"external_v6_address_spec", "locations", b"locations", "maintenance_policy", b"maintenance_policy", "master_logging", b"master_logging", "master_type", b"master_type", "regional_master_spec", b"regional_master_spec", "security_group_ids", b"security_group_ids", "version", b"version", "zonal_master_spec", b"zonal_master_spec"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["master_type", b"master_type"]) -> typing.Literal["zonal_master_spec", "regional_master_spec"] | None: ...

global___MasterSpec = MasterSpec

@typing.final
class ZonalMasterSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONE_ID_FIELD_NUMBER: builtins.int
    INTERNAL_V4_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    EXTERNAL_V4_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    """ID of the availability zone."""
    @property
    def internal_v4_address_spec(self) -> global___InternalAddressSpec:
        """Specification of parameters for internal IPv4 networking."""

    @property
    def external_v4_address_spec(self) -> global___ExternalAddressSpec:
        """Specification of parameters for external IPv4 networking."""

    def __init__(
        self,
        *,
        zone_id: builtins.str = ...,
        internal_v4_address_spec: global___InternalAddressSpec | None = ...,
        external_v4_address_spec: global___ExternalAddressSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["external_v4_address_spec", b"external_v4_address_spec", "internal_v4_address_spec", b"internal_v4_address_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["external_v4_address_spec", b"external_v4_address_spec", "internal_v4_address_spec", b"internal_v4_address_spec", "zone_id", b"zone_id"]) -> None: ...

global___ZonalMasterSpec = ZonalMasterSpec

@typing.final
class RegionalMasterSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REGION_ID_FIELD_NUMBER: builtins.int
    LOCATIONS_FIELD_NUMBER: builtins.int
    EXTERNAL_V4_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    EXTERNAL_V6_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    region_id: builtins.str
    """ID of the availability zone where the master resides."""
    @property
    def locations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MasterLocation]:
        """List of locations where the master will be allocated."""

    @property
    def external_v4_address_spec(self) -> global___ExternalAddressSpec:
        """Specify to allocate a static public IP for the master."""

    @property
    def external_v6_address_spec(self) -> global___ExternalAddressSpec:
        """Specification of parameters for external IPv6 networking."""

    def __init__(
        self,
        *,
        region_id: builtins.str = ...,
        locations: collections.abc.Iterable[global___MasterLocation] | None = ...,
        external_v4_address_spec: global___ExternalAddressSpec | None = ...,
        external_v6_address_spec: global___ExternalAddressSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["external_v4_address_spec", b"external_v4_address_spec", "external_v6_address_spec", b"external_v6_address_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["external_v4_address_spec", b"external_v4_address_spec", "external_v6_address_spec", b"external_v6_address_spec", "locations", b"locations", "region_id", b"region_id"]) -> None: ...

global___RegionalMasterSpec = RegionalMasterSpec

@typing.final
class InternalAddressSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_ID_FIELD_NUMBER: builtins.int
    subnet_id: builtins.str
    """ID of the subnet. If no ID is specified, and there only one subnet in specified zone, an address in this subnet will be allocated."""
    def __init__(
        self,
        *,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id"]) -> None: ...

global___InternalAddressSpec = InternalAddressSpec

@typing.final
class ExternalAddressSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    address: builtins.str
    """IP address."""
    def __init__(
        self,
        *,
        address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["address", b"address"]) -> None: ...

global___ExternalAddressSpec = ExternalAddressSpec

@typing.final
class MasterLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONE_ID_FIELD_NUMBER: builtins.int
    INTERNAL_V4_ADDRESS_SPEC_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    """ID of the availability zone."""
    @property
    def internal_v4_address_spec(self) -> global___InternalAddressSpec:
        """If not specified and there is a single subnet in specified zone, address
        in this subnet will be allocated.
        """

    def __init__(
        self,
        *,
        zone_id: builtins.str = ...,
        internal_v4_address_spec: global___InternalAddressSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["internal_v4_address_spec", b"internal_v4_address_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["internal_v4_address_spec", b"internal_v4_address_spec", "zone_id", b"zone_id"]) -> None: ...

global___MasterLocation = MasterLocation

@typing.final
class LocationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ZONE_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    zone_id: builtins.str
    """ID of the availability zone where the master resides."""
    subnet_id: builtins.str
    """ID of the VPC network's subnet where the master resides.
    If not specified and there is a single subnet in specified zone, address in this subnet will be allocated.
    """
    def __init__(
        self,
        *,
        zone_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["subnet_id", b"subnet_id", "zone_id", b"zone_id"]) -> None: ...

global___LocationSpec = LocationSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.compute.v1.disk_placement_group_pb2
import yandex.cloud.compute.v1.disk_placement_group_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class DiskPlacementGroupServiceStub:
    """A set of methods for managing DiskPlacementGroup resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.GetDiskPlacementGroupRequest,
        yandex.cloud.compute.v1.disk_placement_group_pb2.DiskPlacementGroup,
    ]
    """Returns the specified placement group."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupsRequest,
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupsResponse,
    ]
    """Retrieves the list of placement groups in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.CreateDiskPlacementGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a placement group in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.UpdateDiskPlacementGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified placement group."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.DeleteDiskPlacementGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified placement group."""

    ListDisks: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupDisksRequest,
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupDisksResponse,
    ]
    """Lists disks for the specified placement group."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupOperationsRequest,
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupOperationsResponse,
    ]
    """Lists operations for the specified placement group."""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the disk placement group.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the disk placement group."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the disk placement group."""

class DiskPlacementGroupServiceAsyncStub:
    """A set of methods for managing DiskPlacementGroup resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.GetDiskPlacementGroupRequest,
        yandex.cloud.compute.v1.disk_placement_group_pb2.DiskPlacementGroup,
    ]
    """Returns the specified placement group."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupsRequest,
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupsResponse,
    ]
    """Retrieves the list of placement groups in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.CreateDiskPlacementGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a placement group in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.UpdateDiskPlacementGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified placement group."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.DeleteDiskPlacementGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified placement group."""

    ListDisks: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupDisksRequest,
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupDisksResponse,
    ]
    """Lists disks for the specified placement group."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupOperationsRequest,
        yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupOperationsResponse,
    ]
    """Lists operations for the specified placement group."""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the disk placement group.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the disk placement group."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the disk placement group."""

class DiskPlacementGroupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing DiskPlacementGroup resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.compute.v1.disk_placement_group_service_pb2.GetDiskPlacementGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.disk_placement_group_pb2.DiskPlacementGroup, collections.abc.Awaitable[yandex.cloud.compute.v1.disk_placement_group_pb2.DiskPlacementGroup]]:
        """Returns the specified placement group."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupsResponse]]:
        """Retrieves the list of placement groups in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.compute.v1.disk_placement_group_service_pb2.CreateDiskPlacementGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a placement group in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.compute.v1.disk_placement_group_service_pb2.UpdateDiskPlacementGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified placement group."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.compute.v1.disk_placement_group_service_pb2.DeleteDiskPlacementGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified placement group."""

    @abc.abstractmethod
    def ListDisks(
        self,
        request: yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupDisksRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupDisksResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupDisksResponse]]:
        """Lists disks for the specified placement group."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupOperationsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.disk_placement_group_service_pb2.ListDiskPlacementGroupOperationsResponse]]:
        """Lists operations for the specified placement group."""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the disk placement group.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the disk placement group."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the disk placement group."""

def add_DiskPlacementGroupServiceServicer_to_server(servicer: DiskPlacementGroupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/resourcemanager/v1/folder_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.resourcemanager.v1 import folder_pb2 as yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_folder__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/resourcemanager/v1/folder_service.proto\x12\x1fyandex.cloud.resourcemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a,yandex/cloud/resourcemanager/v1/folder.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"3\n\x10GetFolderRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8f\x01\n\x12ListFoldersRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"h\n\x13ListFoldersResponse\x12\x38\n\x07\x66olders\x18\x01 \x03(\x0b\x32\'.yandex.cloud.resourcemanager.v1.Folder\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc9\x02\n\x13\x43reateFolderRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x04name\x18\x02 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x04 \x03(\x0b\x32@.yandex.cloud.resourcemanager.v1.CreateFolderRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x14\x43reateFolderMetadata\x12\x11\n\tfolder_id\x18\x01 \x01(\t\"\xfb\x02\n\x13UpdateFolderRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x33\n\x04name\x18\x03 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8d\x01\n\x06labels\x18\x05 \x03(\x0b\x32@.yandex.cloud.resourcemanager.v1.UpdateFolderRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x14UpdateFolderMetadata\x12\x11\n\tfolder_id\x18\x01 \x01(\t\"h\n\x13\x44\x65leteFolderRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\x0c\x64\x65lete_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa3\x01\n\x14\x44\x65leteFolderMetadata\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x30\n\x0c\x64\x65lete_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x63\x61ncelled_by\x18\x03 \x01(\t\x12\x30\n\x0c\x63\x61ncelled_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"}\n\x1bListFolderOperationsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"n\n\x1cListFolderOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x84\x0e\n\rFolderService\x12\x93\x01\n\x03Get\x12\x31.yandex.cloud.resourcemanager.v1.GetFolderRequest\x1a\'.yandex.cloud.resourcemanager.v1.Folder\"0\x82\xd3\xe4\x93\x02*\x12(/resource-manager/v1/folders/{folder_id}\x12\x97\x01\n\x04List\x12\x33.yandex.cloud.resourcemanager.v1.ListFoldersRequest\x1a\x34.yandex.cloud.resourcemanager.v1.ListFoldersResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/resource-manager/v1/folders\x12\xac\x01\n\x06\x43reate\x12\x34.yandex.cloud.resourcemanager.v1.CreateFolderRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2*\x1e\n\x14\x43reateFolderMetadata\x12\x06\x46older\x82\xd3\xe4\x93\x02!\"\x1c/resource-manager/v1/folders:\x01*\x12\xb8\x01\n\x06Update\x12\x34.yandex.cloud.resourcemanager.v1.UpdateFolderRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*\x1e\n\x14UpdateFolderMetadata\x12\x06\x46older\x82\xd3\xe4\x93\x02-2(/resource-manager/v1/folders/{folder_id}:\x01*\x12\xc4\x01\n\x06\x44\x65lete\x12\x34.yandex.cloud.resourcemanager.v1.DeleteFolderRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*-\n\x14\x44\x65leteFolderMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02**(/resource-manager/v1/folders/{folder_id}\x12\xca\x01\n\x0eListOperations\x12<.yandex.cloud.resourcemanager.v1.ListFolderOperationsRequest\x1a=.yandex.cloud.resourcemanager.v1.ListFolderOperationsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/resource-manager/v1/folders/{folder_id}/operations\x12\xbc\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/resource-manager/v1/folders/{resource_id}:listAccessBindings\x12\xfb\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x93\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x41\"</resource-manager/v1/folders/{resource_id}:setAccessBindings:\x01*\x12\x87\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x99\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x44\"?/resource-manager/v1/folders/{resource_id}:updateAccessBindings:\x01*Bz\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.resourcemanager.v1.folder_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanager'
  _GETFOLDERREQUEST.fields_by_name['folder_id']._options = None
  _GETFOLDERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFOLDERSREQUEST.fields_by_name['cloud_id']._options = None
  _LISTFOLDERSREQUEST.fields_by_name['cloud_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFOLDERSREQUEST.fields_by_name['page_size']._options = None
  _LISTFOLDERSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTFOLDERSREQUEST.fields_by_name['page_token']._options = None
  _LISTFOLDERSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _LISTFOLDERSREQUEST.fields_by_name['filter']._options = None
  _LISTFOLDERSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _CREATEFOLDERREQUEST_LABELSENTRY._options = None
  _CREATEFOLDERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEFOLDERREQUEST.fields_by_name['cloud_id']._options = None
  _CREATEFOLDERREQUEST.fields_by_name['cloud_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEFOLDERREQUEST.fields_by_name['name']._options = None
  _CREATEFOLDERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATEFOLDERREQUEST.fields_by_name['description']._options = None
  _CREATEFOLDERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEFOLDERREQUEST.fields_by_name['labels']._options = None
  _CREATEFOLDERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _UPDATEFOLDERREQUEST_LABELSENTRY._options = None
  _UPDATEFOLDERREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEFOLDERREQUEST.fields_by_name['folder_id']._options = None
  _UPDATEFOLDERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEFOLDERREQUEST.fields_by_name['name']._options = None
  _UPDATEFOLDERREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _UPDATEFOLDERREQUEST.fields_by_name['description']._options = None
  _UPDATEFOLDERREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEFOLDERREQUEST.fields_by_name['labels']._options = None
  _UPDATEFOLDERREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _DELETEFOLDERREQUEST.fields_by_name['folder_id']._options = None
  _DELETEFOLDERREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFOLDEROPERATIONSREQUEST.fields_by_name['folder_id']._options = None
  _LISTFOLDEROPERATIONSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFOLDEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTFOLDEROPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTFOLDEROPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTFOLDEROPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _FOLDERSERVICE.methods_by_name['Get']._options = None
  _FOLDERSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/resource-manager/v1/folders/{folder_id}'
  _FOLDERSERVICE.methods_by_name['List']._options = None
  _FOLDERSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\036\022\034/resource-manager/v1/folders'
  _FOLDERSERVICE.methods_by_name['Create']._options = None
  _FOLDERSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateFolderMetadata\022\006Folder\202\323\344\223\002!\"\034/resource-manager/v1/folders:\001*'
  _FOLDERSERVICE.methods_by_name['Update']._options = None
  _FOLDERSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateFolderMetadata\022\006Folder\202\323\344\223\002-2(/resource-manager/v1/folders/{folder_id}:\001*'
  _FOLDERSERVICE.methods_by_name['Delete']._options = None
  _FOLDERSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteFolderMetadata\022\025google.protobuf.Empty\202\323\344\223\002**(/resource-manager/v1/folders/{folder_id}'
  _FOLDERSERVICE.methods_by_name['ListOperations']._options = None
  _FOLDERSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0025\0223/resource-manager/v1/folders/{folder_id}/operations'
  _FOLDERSERVICE.methods_by_name['ListAccessBindings']._options = None
  _FOLDERSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002?\022=/resource-manager/v1/folders/{resource_id}:listAccessBindings'
  _FOLDERSERVICE.methods_by_name['SetAccessBindings']._options = None
  _FOLDERSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002A\"</resource-manager/v1/folders/{resource_id}:setAccessBindings:\001*'
  _FOLDERSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _FOLDERSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002D\"?/resource-manager/v1/folders/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETFOLDERREQUEST']._serialized_start=371
  _globals['_GETFOLDERREQUEST']._serialized_end=422
  _globals['_LISTFOLDERSREQUEST']._serialized_start=425
  _globals['_LISTFOLDERSREQUEST']._serialized_end=568
  _globals['_LISTFOLDERSRESPONSE']._serialized_start=570
  _globals['_LISTFOLDERSRESPONSE']._serialized_end=674
  _globals['_CREATEFOLDERREQUEST']._serialized_start=677
  _globals['_CREATEFOLDERREQUEST']._serialized_end=1006
  _globals['_CREATEFOLDERREQUEST_LABELSENTRY']._serialized_start=961
  _globals['_CREATEFOLDERREQUEST_LABELSENTRY']._serialized_end=1006
  _globals['_CREATEFOLDERMETADATA']._serialized_start=1008
  _globals['_CREATEFOLDERMETADATA']._serialized_end=1049
  _globals['_UPDATEFOLDERREQUEST']._serialized_start=1052
  _globals['_UPDATEFOLDERREQUEST']._serialized_end=1431
  _globals['_UPDATEFOLDERREQUEST_LABELSENTRY']._serialized_start=961
  _globals['_UPDATEFOLDERREQUEST_LABELSENTRY']._serialized_end=1006
  _globals['_UPDATEFOLDERMETADATA']._serialized_start=1433
  _globals['_UPDATEFOLDERMETADATA']._serialized_end=1474
  _globals['_DELETEFOLDERREQUEST']._serialized_start=1476
  _globals['_DELETEFOLDERREQUEST']._serialized_end=1580
  _globals['_DELETEFOLDERMETADATA']._serialized_start=1583
  _globals['_DELETEFOLDERMETADATA']._serialized_end=1746
  _globals['_LISTFOLDEROPERATIONSREQUEST']._serialized_start=1748
  _globals['_LISTFOLDEROPERATIONSREQUEST']._serialized_end=1873
  _globals['_LISTFOLDEROPERATIONSRESPONSE']._serialized_start=1875
  _globals['_LISTFOLDEROPERATIONSRESPONSE']._serialized_end=1985
  _globals['_FOLDERSERVICE']._serialized_start=1988
  _globals['_FOLDERSERVICE']._serialized_end=3784
# @@protoc_insertion_point(module_scope)
